from os import environ, makedirs, path
import yaml

class ConfigFile:
    def __init__(self, filepath: str, init_values = None):
        self.values = {}
        if init_values:
            self.values = init_values
        self.filepath = filepath
        if path.isfile(self.filepath):
            with open(self.filepath, "r") as file:
                self.values |= yaml.safe_load(file)

    def save(self):
        if not self.filepath: return
        directory = path.dirname(self.filepath)
        if not path.isdir(directory):
            makedirs(directory)
        with open(self.filepath, "w") as file:
            yaml.dump(self.values, file)

    def get(self, name: str, default=None):
        if name in self.values: return self.values[name]
        return default

    def set(self, name: str, value):
        self.values[name] = value

    def get_values(self):
        return self.values.copy()

    def set_values(self, values):
        self.values = values